<template>
  <div class="mod-config">
    <basic-container>
      <el-row>
        <el-col :span="12">
          <ttable
            :table="table"
            @currentChange="handleCurrentChange"
            :uploadInfo="uploadInfo"
            :isShowHide="true"
            :prelang="prelang"
            :options="options"
            :ajaxFun="ajaxFun"
            ref="partFamilyTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
        <el-col :span="12" style="padding-left: 10px">
          <ttable
            :table="joinTable"
            :uploadInfo="joinUploadInfo"
            :isShowHide="true"
            :prelang="joinPrelang"
            :options="joinOptions"
            :ajaxFun="joinAjaxFun"
            :paramObj="paramObj"
            ref="joinStaffTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
      </el-row>

      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/basic/post'
import { fetchList as fetchListStaff } from '@/api/basic/staff'
import TableForm from './post-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'

export default {
  data() {
    return {
      currentPostId: 0,
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'postNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件族编号
          {
            minWidth: '30',
            prop: 'postNo',
            label: '岗位编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 零件族名称
          {
            minWidth: '120',
            prop: 'postName',
            label: '岗位名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 描述
          {
            minWidth: '120',
            prop: 'remark',
            label: '描述',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            icon: 'el-icon-delete',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 60,
          minWidth: 60
        }
      },

      paramObj: { postId: 0 },
      joinAjaxFun: fetchListStaff,
      joinUploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      joinPrelang: 'operation',
      joinOptions: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'staffNo', direction: 'desc' }
      },
      joinTable: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '100',
            prop: 'staffNo',
            label: '人员编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'staffName',
            label: '人员名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [],
        operator: null,
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 60,
          minWidth: 60
        }
      }
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.partFamilyTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除编号为' + row.postNo, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },

    getJoinData() {
      this.$refs.joinStaffTable.getDataList()
    },
    handleCurrentChange(row) {
      if (!row) {
        this.currentPostId = null
        this.paramObj = { postId: 0 }
      } else if (!this.currentPostId || this.currentPostId != row.id) {
        this.currentPostId = row.id
        this.paramObj = { postId: row.id }
      }
      this.$nextTick(() => {
        this.getJoinData()
      })
    }
  }
}
</script>
